"use strict";
// import * as path from 'path'
Object.defineProperty(exports, "__esModule", { value: true });
exports.eksStack = void 0;
const iam = require("@aws-cdk/aws-iam");
const ec2 = require("@aws-cdk/aws-ec2");
const eks = require("@aws-cdk/aws-eks");
function eksStack(stack, props) {
    var _a;
    let myVPC;
    if (props.vpcId) {
        myVPC = ec2.Vpc.fromLookup(stack, `VPC-${props.baseName}`, { vpcId: props.vpcId });
    }
    else if (props.cidr) {
        myVPC = new ec2.Vpc(stack, `VPC-${props.baseName}`, {
            cidr: props.cidr,
        });
    }
    else {
        throw Error('we need a vpcid or cidr');
    }
    const clusterAdmin = new iam.Role(stack, `Role-${props.baseName}-clusterAdmin`, {
        assumedBy: new iam.AccountRootPrincipal(),
    });
    const eksCluster = new eks.Cluster(stack, `EKS-${props.baseName}`, {
        clusterName: `${props.baseName}`,
        mastersRole: clusterAdmin,
        vpc: myVPC,
        kubectlEnabled: true,
        defaultCapacity: 0,
        version: props.EKSVersion || eks.KubernetesVersion.V1_17,
    });
    (_a = props.clusterAdminRoleArns) === null || _a === void 0 ? void 0 : _a.forEach((i) => {
        eksCluster.awsAuth.addMastersRole(iam.Role.fromRoleArn(stack, `Role-eks-mainroles-${i.replace(/[^a-zA-Z0-9]+/g, '-')}`, i));
    });
    eksCluster.addManifest(`SC-${props.baseName}-gp2-encrypted`, {
        apiVersion: 'storage.k8s.io/v1',
        kind: 'StorageClass',
        metadata: {
            name: 'gp2-encrypted',
        },
        provisioner: 'kubernetes.io/aws-ebs',
        parameters: {
            type: 'gp2',
            encrypted: 'true',
        },
        reclaimPolicy: 'Retain',
        allowVolumeExpansion: true,
    });
    return {
        props,
        eks: eksCluster,
    };
}
exports.eksStack = eksStack;
//# sourceMappingURL=eks-stack.js.map